/*
 * Project name:
     KeyPad on CoG
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20101007:
       - initial release;
       - 20101007 - Ranko Rankovic;
 * Description:
     This project will demonstrate how keys pressed on KeyPad are written on CoG.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     dev.board:       http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/
     Oscillator:      HS, 8.0000 MHz
     Ext. Modules:    KeyPad 4x4 Module:
                      http://www.mikroe.com/eng/products/view/135/keypad-4x4-board/
     SW:              mikroBasic PRO for 8051 v2.20
                      http://www.mikroe.com/en/compilers/mikroc/pro/pic/
 * NOTES:
     - Make sure you turn ON the CoG and Port Expander switches (SW9.1-SW9.6 and SW6.2-SW6.6)
*/



unsigned short kp, cnt, oldstate = 0;
char txt[6];

// Keypad module connections
char keypadPort at P0;
// End Keypad module connections

// Port Expander module connections
sbit  SPExpanderRST at P3_7_bit;
sbit  SPExpanderCS  at P3_4_bit;
// End Port Expander module connections


void main() {
  cnt = 0;                                 // Reset counter
  Keypad_Init();                           // Initialize Keypad
  SPI1_Init();                             // Initialize Lcd
  Delay_ms(100);
  SPI_Lcd_Config(0);                       // Initialize Lcd over SPI interface
  Delay_ms(100);
  SPI_Lcd_Cmd(_LCD_CLEAR);                 // Clear display
  SPI_Lcd_Cmd(_LCD_CURSOR_OFF);            // Cursor off

  SPI_Lcd_Out(1, 1, "Key  :");             // Write message text on Lcd
  SPI_Lcd_Out(2, 1, "Times:");

  do {
    kp = 0;                                // Reset key code variable

    // Wait for key to be pressed and released
    do
      kp = Keypad_Key_Click();             // Store key code in kp variable
    while (!kp);
   // Prepare value for output, transform key to it's ASCII value
    switch (kp) {

      case  1: kp = 49; break; // 1        // Uncomment this block for keypad4x4
      case  2: kp = 50; break; // 2
      case  3: kp = 51; break; // 3
      case  4: kp = 65; break; // A
      case  5: kp = 52; break; // 4
      case  6: kp = 53; break; // 5
      case  7: kp = 54; break; // 6
      case  8: kp = 66; break; // B
      case  9: kp = 55; break; // 7
      case 10: kp = 56; break; // 8
      case 11: kp = 57; break; // 9
      case 12: kp = 67; break; // C
      case 13: kp = 42; break; // *
      case 14: kp = 48; break; // 0
      case 15: kp = 35; break; // #
      case 16: kp = 68; break; // D

    }

    if (kp != oldstate) {                  // Pressed key differs from previous
      cnt = 1;
      oldstate = kp;
      }
    else {                                 // Pressed key is same as previous
      cnt++;
      }

    SPI_Lcd_Chr(1, 10, kp);                // Print key ASCII value on Lcd

    if (cnt == 255) {                      // If counter varialble overflow
      cnt = 0;
      SPI_Lcd_Out(2, 10, "   ");
      }

    WordToStr(cnt, txt);                   // Transform counter value to string
    SPI_Lcd_Out(2, 10, txt);               // Display counter value on Lcd
  } while (1);
}
