/*
 * Project name:
     KeyPad over RS232
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20101007:
       - initial release;
       - 20101007 - Ranko Rankovic;
 * Description:
     This project will demonstrate how keys pressed on KeyPad are send over RS232.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     dev.board:       http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/
     Oscillator:      HS, 8.0000 MHz
     Ext. Modules:    KeyPad 4x4 Module:
                      http://www.mikroe.com/eng/products/view/135/keypad-4x4-board/
     SW:              mikroC PRO for 8051 v2.20
                      http://www.mikroe.com/en/compilers/mikroc/pro/pic/
 * NOTES:
     - Make sure you turn ON the RS232 switches (SW8.5 and SW8.6)
*/



unsigned short kp;
char txt[6];

// Keypad module connections
char keypadPort at P0;
// End Keypad module connections


void main() {
  Keypad_Init();                           // Initialize Keypad

  UART1_Init(4800);               // Initialize UART module at 9600 bps
  Delay_ms(100);                  // Wait for UART module to stabilize

  UART1_Write_Text("Start");
  UART1_Write(10);
  UART1_Write(13);

  do {
    kp = 0;                                // Reset key code variable

    // Wait for key to be pressed and released
    do
      kp = Keypad_Key_Click();             // Store key code in kp variable
    while (!kp);
   // Prepare value for output, transform key to it's ASCII value
    switch (kp) {


      case  1: kp = 49; break; // 1
      case  2: kp = 50; break; // 2
      case  3: kp = 51; break; // 3
      case  4: kp = 65; break; // A
      case  5: kp = 52; break; // 4
      case  6: kp = 53; break; // 5
      case  7: kp = 54; break; // 6
      case  8: kp = 66; break; // B
      case  9: kp = 55; break; // 7
      case 10: kp = 56; break; // 8
      case 11: kp = 57; break; // 9
      case 12: kp = 67; break; // C
      case 13: kp = 42; break; // *
      case 14: kp = 48; break; // 0
      case 15: kp = 35; break; // #
      case 16: kp = 68; break; // D

    }

    UART1_Write(kp);                       // Send data via UART
    UART1_Write(10);
    UART1_Write(13);
  } while (1);
}
