/*
 * Project name:
     KeyPad on LED
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20101007:
       - initial release;
       - 20101007 - Ranko Rankovic;
 * Description:
     This project will demonstrate how keys pressed on KeyPad are written on LED.
* Test configuration:
     MCU:             ac:PIC16F887
     Dev.Board:       ac:EasyPIC6
     Oscillator:      HS, 8.0000 MHz
     Ext. Modules:    ac:KeyPad_4x4_Module
     SW:              ac:mikroC_PRO_for_PIC_v4.15
 * NOTES:
     - Turn ON the PortB and PortC LEDs (SW9.2 and SW9.3)
     - Connect KeyPad on PortD
*/




unsigned short kp, cnt, oldstate = 0;
char txt[6];

// Keypad module connections
char  keypadPort at PORTD;
// End Keypad module connections

void main() {
  cnt = 0;                                 // Reset counter
  Keypad_Init();                           // Initialize Keypad
  ANSEL  = 0;                              // Configure AN pins as digital I/O
  ANSELH = 0;
  
  TRISB = 0x00;                            //  set direction to be output
  TRISC = 0x00;                            // set direction to be output

  do {
    kp = 0;                                // Reset key code variable

    // Wait for key to be pressed and released
    do
      kp = Keypad_Key_Click();             // Store key code in kp variable
    while (!kp);
   // Prepare value for output, transform key to it's ASCII value
    switch (kp) {


      case  1: kp = 49; break; // 1        // Uncomment this block for keypad4x4
      case  2: kp = 50; break; // 2
      case  3: kp = 51; break; // 3
      case  4: kp = 65; break; // A
      case  5: kp = 52; break; // 4
      case  6: kp = 53; break; // 5
      case  7: kp = 54; break; // 6
      case  8: kp = 66; break; // B
      case  9: kp = 55; break; // 7
      case 10: kp = 56; break; // 8
      case 11: kp = 57; break; // 9
      case 12: kp = 67; break; // C
      case 13: kp = 42; break; // *
      case 14: kp = 48; break; // 0
      case 15: kp = 35; break; // #
      case 16: kp = 68; break; // D

    }

    if (kp != oldstate) {                  // Pressed key differs from previous
      cnt = 1;
      oldstate = kp;
    }
    else {                                 // Pressed key is same as previous
      cnt++;
    }

    PORTB = kp;                            // Print key ASCII value on LED

    if (cnt == 255) {                      // If counter varialble overflow
      cnt = 0;
      PORTC = cnt;
    }

    PORTC = cnt;
  } while (1);
}