/*
 * Project name:
     KeyPad on CoG
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20101007:
       - initial release;
       - 20101007 - Ranko Rankovic;
 * Description:
     This project will demonstrate how keys pressed on KeyPad are written on CoG.
 * Test configuration:
     MCU:             ac:dsPIC30F4013
     Dev.Board:       ac:EasydsPIC6
     Oscillator:      HS, 10.0 MHz
     Ext. Modules:    ac:KeyPad_4x4_Module
     SW:              ac:mikroC_PRO_for_dsPIC_v4.10
 * NOTES:
     - Make sure you turn ON the CoG and Port Expander switches (SW11.1-SW11.5 and SW10.1-SW10.6)
     - Connect KeyPad on PortB
*/



unsigned short kp, cnt, oldstate = 0;
char txt[6];

// Keypad module connections
unsigned keypadPort at PORTB;
unsigned keypadPort_Direction at TRISB;
// End Keypad module connections

// Port Expander module connections
sbit  SPExpanderRST at RB11_bit;
sbit  SPExpanderCS  at RB10_bit;
sbit  SPExpanderRST_Direction at TRISB11_bit;
sbit  SPExpanderCS_Direction  at TRISB10_bit;
// End Port Expander module connections

void main() {

  ADPCFG = 0xFFFF;

  Keypad_Init();                           // Initialize Keypad

  SPI1_Init();                      // Initialize SPI module used with PortExpander
  Delay_ms(100);
  SPI_Lcd_Config(0);                // Initialize Lcd over SPI interface
  Delay_ms(100);
  SPI_Lcd_Cmd(_LCD_CLEAR);          // Clear display
  SPI_Lcd_Cmd(_LCD_CURSOR_OFF);     // Turn cursor off
  SPI_Lcd_Out(1,1, "1");
  SPI_Lcd_Out(1,1, "Key  :");
  SPI_Lcd_Out(2,1, "Times:");       // Print frequency to Lcd

  do {
    kp = 0;                         // Reset key code variable

    // Wait for key to be pressed and released
    do
      kp = Keypad_Key_Click();      // Store key code in kp variable
    while (!kp);
    // Prepare value for output, transform key to it's ASCII value
    switch (kp) {

      case  1: kp = 49; break; // 1
      case  2: kp = 50; break; // 2
      case  3: kp = 51; break; // 3
      case  4: kp = 65; break; // A
      case  5: kp = 52; break; // 4
      case  6: kp = 53; break; // 5
      case  7: kp = 54; break; // 6
      case  8: kp = 66; break; // B
      case  9: kp = 55; break; // 7
      case 10: kp = 56; break; // 8
      case 11: kp = 57; break; // 9
      case 12: kp = 67; break; // C
      case 13: kp = 42; break; // *
      case 14: kp = 48; break; // 0
      case 15: kp = 35; break; // #
      case 16: kp = 68; break; // D

    }

    if (kp != oldstate) {           // Pressed key differs from previous
      cnt = 1;
      oldstate = kp;
      }
    else {                          // Pressed key is same as previous
      cnt++;
      }

    SPI_Lcd_Chr(1, 10, kp);         // Print key ASCII value on LCD

    if (cnt == 255) {               // If counter varialble overflow
      cnt = 0;
      SPI_Lcd_Out(2, 10, "   ");
      }

    WordToStr(cnt, txt);            // Transform counter value to string
    SPI_Lcd_Out(2, 10, txt);        // Display counter value on LCD
  } while (1);
}