/*
 * Project name:
     KeyPad on LED
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20101007:
       - initial release;
       - 20101007 - Ranko Rankovic;
 * Description:
     This project will demonstrate how keys pressed on KeyPad are written on LED.
 * Test configuration:
     MCU:             ac:dsPIC30F4013
     Dev.Board:       ac:EasydsPIC6
     Oscillator:      HS, 10.0 MHz
     Ext. Modules:    ac:KeyPad_4x4_Module
     SW:              ac:mikroC_PRO_for_dsPIC_v4.10
 * NOTES:
     - Turn on LEDS on PortD and PortF (SW12.2 and SW12.4)
     - Connect KeyPad on PortB
*/




unsigned short kp, cnt, oldstate = 0;
char txt[6];

// Keypad module connections
unsigned keypadPort at PORTB;
unsigned keypadPort_Direction at TRISB;
// End Keypad module connections


void main() {

  ADPCFG = 0xFFFF;
  
  TRISF = 0;             // Initialize PORTC as output
  TRISD = 0;             // Initialize PORTD as output

  Keypad_Init();                           // Initialize Keypad


  do {
    kp = 0;                         // Reset key code variable

    // Wait for key to be pressed and released
    do
      kp = Keypad_Key_Click();      // Store key code in kp variable
    while (!kp);
    // Prepare value for output, transform key to it's ASCII value
    switch (kp) {

      case  1: kp = 49; break; // 1
      case  2: kp = 50; break; // 2
      case  3: kp = 51; break; // 3
      case  4: kp = 65; break; // A
      case  5: kp = 52; break; // 4
      case  6: kp = 53; break; // 5
      case  7: kp = 54; break; // 6
      case  8: kp = 66; break; // B
      case  9: kp = 55; break; // 7
      case 10: kp = 56; break; // 8
      case 11: kp = 57; break; // 9
      case 12: kp = 67; break; // C
      case 13: kp = 42; break; // *
      case 14: kp = 48; break; // 0
      case 15: kp = 35; break; // #
      case 16: kp = 68; break; // D

    }

    if (kp != oldstate) {           // Pressed key differs from previous
      cnt = 1;
      oldstate = kp;
      }
    else {                          // Pressed key is same as previous
      cnt++;
      }

    LATF = kp;         // Print key ASCII value on LCD

    if (cnt == 255) {               // If counter varialble overflow
      cnt = 0;
      LATD = 0x00;
      }

    LATD = cnt;
    
  } while (1);
}