/*
 * Project name:
     KeyPad over RS232
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20101007:
       - initial release;
       - 20101007 - Ranko Rankovic;
 * Description:
     This project will demonstrate how keys pressed on KeyPad are send over RS232.
 * Test configuration:
     MCU:             ac:dsPIC30F4013
     Dev.Board:       ac:EasydsPIC6
     Oscillator:      HS, 10.0 MHz
     Ext. Modules:    ac:KeyPad_4x4_Module
     SW:              ac:mikroC_PRO_for_dsPIC_v4.10
 * NOTES:
     - Turn on RS232 (SW7.2 and SW7.6)
     - Connect KeyPad on PortB
*/





unsigned short kp, oldstate = 0;
char txt[6];

// Keypad module connections
unsigned keypadPort at PORTB;
unsigned keypadPort_Direction at TRISB;
// End Keypad module connections

void main() {
  ADPCFG = 0xFFFF;
  UART1_Init(9600);
  Delay_ms(100);
  Keypad_Init();                           // Initialize Keypad

  do {
    kp = 0;                                // Reset key code variable

    // Wait for key to be pressed and released
    do
      kp = Keypad_Key_Click();             // Store key code in kp variable
    while (!kp);
   // Prepare value for output, transform key to it's ASCII value
    switch (kp) {

      case  1: kp = 49; break; // 1
      case  2: kp = 50; break; // 2
      case  3: kp = 51; break; // 3
      case  4: kp = 65; break; // A
      case  5: kp = 52; break; // 4
      case  6: kp = 53; break; // 5
      case  7: kp = 54; break; // 6
      case  8: kp = 66; break; // B
      case  9: kp = 55; break; // 7
      case 10: kp = 56; break; // 8
      case 11: kp = 57; break; // 9
      case 12: kp = 67; break; // C
      case 13: kp = 42; break; // *
      case 14: kp = 48; break; // 0
      case 15: kp = 35; break; // #
      case 16: kp = 68; break; // D

    }
    UART1_Write(kp);                       // Send value of pressed button to UART
  } while (1);
}